<?php
/*
* 2014 Jose Aguilar
*
*  @author Jose Aguilar <josely1984@hotmail.com>
*  @copyright  2004 Jose Aguilar
*  http://www.jose-aguilar.com/
 * 
 * http://www.myjqueryplugins.com/jquery-plugin/jrating
 * 
 * VERSION 1.0 (07/03/2014)
 * 
 * VERSION 1.1 (08/03/2014)
 * ADD: Select position or hook in product page
 * 
 * VERSION 1.2 (01/05/2014)
 * FIX: url modules dir in tpl prestashop 1.6
*
*/

if (!defined('_PS_VERSION_'))
  exit;
 
class Jratingproduct extends Module
{
    public $output;
    public $types = array('big', 'small');
    public $hooks = array('HOOK_EXTRA_LEFT', 'HOOK_PRODUCT_ACTIONS', 'HOOK_EXTRA_RIGHT', 'HOOK_PRODUCT_FOOTER', 'HOOK_PRODUCT_TAB');
    
    public function __construct()
    {
        $this->name = 'jratingproduct';
        $this->tab = 'front_office_features';
        $this->version = '1.2';
        $this->author = 'Jose Aguilar';
        $this->need_instance = 0;

        parent::__construct();

        $this->displayName = $this->l('jRating Product');
        $this->description = $this->l('Rating stars with jRating plugin.');

        $this->confirmUninstall = $this->l('Are you sure you want to uninstall? All reviews will be lost...');
    }
  
    public function install() {
        Configuration::updateValue('JRATINGPRODUCT_TYPE', 'big');
        Configuration::updateValue('JRATINGPRODUCT_LENGTH', 5);
        Configuration::updateValue('JRATINGPRODUCT_RATEMAX', 5);
        Configuration::updateValue('JRATINGPRODUCT_DECIMALLENGTH', 0);
        Configuration::updateValue('JRATINGPRODUCT_NBRATES', 1);
        Configuration::updateValue('JRATINGPRODUCT_HOOK', 'HOOK_EXTRA_RIGHT');
        return parent::install() 
                && $this->registerHook('displayRightColumnProduct') 
                && $this->registerHook('displayLeftColumnProduct') 
                && $this->registerHook('displayProductButtons') 
                && $this->registerHook('displayFooterProduct') 
                && $this->registerHook('displayProductTab') 
                && $this->registerHook('displayProductTabContent') 
                && $this->registerHook('displayHeader') 
                && $this->createTables();
    }
  
    public function uninstall() {
        
        Configuration::deleteByName('JRATINGPRODUCT_TYPE');
        Configuration::deleteByName('JRATINGPRODUCT_LENGTH');
        Configuration::deleteByName('JRATINGPRODUCT_RATEMAX');
        Configuration::deleteByName('JRATINGPRODUCT_DECIMALLENGTH');
        Configuration::deleteByName('JRATINGPRODUCT_NBRATES');
        Configuration::deleteByName('JRATINGPRODUCT_HOOK');
        
        if (!parent::uninstall() || !$this->deleteTables())
            return false;
        return true;
    }
  
    public function createTables() {
        Db::getInstance()->Execute('CREATE TABLE IF NOT EXISTS `'._DB_PREFIX_.'product_rating` (
                                `id_rating` int( 10 ) NOT NULL AUTO_INCREMENT ,
                                `id_product` int( 10 ) NOT NULL ,
                                `rate` int( 10 ) NOT NULL ,
                                PRIMARY KEY ( `id_rating` )
                                ) ENGINE = InnoDB DEFAULT CHARSET=utf8;');
		
        return true;
    }
	
    public function deleteTables() {
        Db::getInstance()->Execute('DROP TABLE `'._DB_PREFIX_.'product_rating`');
	return true;
    }
    
    public function postProcess() {
        if (Tools::isSubmit('submitSettings')) {
            Configuration::updateValue('JRATINGPRODUCT_TYPE', Tools::getValue('JRATINGPRODUCT_TYPE'));
            Configuration::updateValue('JRATINGPRODUCT_LENGTH', Tools::getValue('JRATINGPRODUCT_LENGTH'));
            Configuration::updateValue('JRATINGPRODUCT_RATEMAX', Tools::getValue('JRATINGPRODUCT_RATEMAX'));
            Configuration::updateValue('JRATINGPRODUCT_DECIMALLENGTH', Tools::getValue('JRATINGPRODUCT_DECIMALLENGTH'));   
            Configuration::updateValue('JRATINGPRODUCT_HOOK', Tools::getValue('JRATINGPRODUCT_HOOK'));   
            $this->output .= $this->displayConfirmation($this->l('The settings was successfully added.'));
        }
    }
    
    public function getContent() {
        
        $this->output .= '<h2><img src="../modules/' . $this->name . '/logo.png" /> '.$this->displayName.' '.$this->l('version').' '.$this->version.'</h2>';
        
        $this->postProcess();
        
        return $this->displayForm();
    }
    
    public function displayForm() {
        $this->output .= '<form action="'.Tools::safeOutput($_SERVER['REQUEST_URI']).'" method="post">';
        $this->output .= '<fieldset><legend>'.$this->l('Global Settings').'</legend>';
        
        $this->output .= '
		<label for="controls">'.$this->l('Position in page product').'</label>
		<div class="margin-form">
			<input type="radio" name="JRATINGPRODUCT_HOOK" id="controls" '.(Configuration::get('JRATINGPRODUCT_HOOK') == 'HOOK_EXTRA_LEFT' ? 'checked="checked"' : '').' value="HOOK_EXTRA_LEFT" />
			<label class="t" for="controls_on">HOOK_EXTRA_LEFT</label><br/>
			<input type="radio" name="JRATINGPRODUCT_HOOK" id="automatic_off" '.(Configuration::get('JRATINGPRODUCT_HOOK') == 'HOOK_PRODUCT_ACTIONS' ? 'checked="checked" ' : '').' value="HOOK_PRODUCT_ACTIONS" />
			<label class="t" for="controls_off">HOOK_PRODUCT_ACTIONS</label><br/>
                        <input type="radio" name="JRATINGPRODUCT_HOOK" id="automatic_off" '.(Configuration::get('JRATINGPRODUCT_HOOK') == 'HOOK_EXTRA_RIGHT' ? 'checked="checked" ' : '').' value="HOOK_EXTRA_RIGHT" />
			<label class="t" for="controls_off">HOOK_EXTRA_RIGHT</label><br/>
                        <input type="radio" name="JRATINGPRODUCT_HOOK" id="automatic_off" '.(Configuration::get('JRATINGPRODUCT_HOOK') == 'HOOK_PRODUCT_FOOTER' ? 'checked="checked" ' : '').' value="HOOK_PRODUCT_FOOTER" />
			<label class="t" for="controls_off">HOOK_PRODUCT_FOOTER</label><br/>
                        <input type="radio" name="JRATINGPRODUCT_HOOK" id="automatic_off" '.(Configuration::get('JRATINGPRODUCT_HOOK') == 'HOOK_PRODUCT_TAB' ? 'checked="checked" ' : '').' value="HOOK_PRODUCT_TAB" />
			<label class="t" for="controls_off">HOOK_PRODUCT_TAB</label><br/>
		</div>';
        
        $this->output .= '
		<label for="controls">'.$this->l('Star type').'</label>
		<div class="margin-form">
			<input type="radio" name="JRATINGPRODUCT_TYPE" id="controls" '.(Configuration::get('JRATINGPRODUCT_TYPE') == 'big' ? 'checked="checked"' : '').' value="big" />
			<label class="t" for="controls_on">'.$this->l('Big').'</label><br/>
			<input type="radio" name="JRATINGPRODUCT_TYPE" id="automatic_off" '.(Configuration::get('JRATINGPRODUCT_TYPE') == 'small' ? 'checked="checked" ' : '').' value="small" />
			<label class="t" for="controls_off">'.$this->l('Small').'</label>
		</div>';
        
        $this->output .= '<label>'.$this->l('Number of stars').'</label>
                          <div class="margin-form">
                            <select name="JRATINGPRODUCT_LENGTH">';
					
                            for ($i=2; $i<21; $i++) {
				if ((int)Configuration::get('JRATINGPRODUCT_LENGTH') == $i)
                                    $this->output .= '<option value="'.$i.'" selected="selected">'.$i.'</option>';
				else
                                    $this->output .= '<option value="'.$i.'">'.$i.'</option>';
                            }
								
	$this->output .= '</select></div>';
        
        $this->output .= '<label>'.$this->l('Maximal rate').'</label>
                          <div class="margin-form">
                            <select name="JRATINGPRODUCT_RATEMAX">';
					
                            for ($i=2; $i<21; $i++) {
				if ((int)Configuration::get('JRATINGPRODUCT_RATEMAX') == $i)
                                    $this->output .= '<option value="'.$i.'" selected="selected">'.$i.'</option>';
				else
                                    $this->output .= '<option value="'.$i.'">'.$i.'</option>';
                            }
								
	$this->output .= '</select></div>';
        
        $this->output .= '<label>'.$this->l('Number of decimal in the rate').'</label>
                          <div class="margin-form">
                            <select name="JRATINGPRODUCT_DECIMALLENGTH">';
					
                            for ($i=0; $i<5; $i++) {
				if ((int)Configuration::get('JRATINGPRODUCT_DECIMALLENGTH') == $i)
                                    $this->output .= '<option value="'.$i.'" selected="selected">'.$i.'</option>';
				else
                                    $this->output .= '<option value="'.$i.'">'.$i.'</option>';
                            }
								
	$this->output .= '</select></div>';
        
        $this->output .= '<div class="margin-form">
                            <input type="submit" name="submitSettings" value="'.$this->l('Save').'" class="button" />
                        </div>';
        
        $this->output .= '</fieldset>';
	$this->output .= '</form>';
        
        return $this->output;
    }
    
    public function addRate($id_product, $rate) {
        $insert_rate = 'INSERT INTO `'._DB_PREFIX_.'product_rating`(`id_product`, `rate`) VALUES ('.$id_product.', '.$rate.')';
        Db::getInstance()->Execute($insert_rate);
    }
    
    public function getDataFrontOffice() {
        $id_product = Tools::getValue('id_product');
        
        $query_num_rates = 'SELECT COUNT(*) as num FROM '._DB_PREFIX_.'product_rating WHERE id_product = '.$id_product;
        $num_rates = Db::getInstance()->getValue($query_num_rates);
        
        $query_sum_rates = 'SELECT SUM(rate) as num FROM '._DB_PREFIX_.'product_rating WHERE id_product = '.$id_product;
        $sum_rates = Db::getInstance()->getValue($query_sum_rates);
        
        $rate = 0;
        
        if ($num_rates > 0) {
            $rate = round($sum_rates / $num_rates);
         }
        
        $this->context->smarty->assign(
            array(
                'id_product' => $id_product,
                'rate' => $rate,
                'type' => Configuration::get('JRATINGPRODUCT_TYPE'),
                'length' => Configuration::get('JRATINGPRODUCT_LENGTH'),
                'ratemax' => Configuration::get('JRATINGPRODUCT_RATEMAX'),
                'decimallength' => Configuration::get('JRATINGPRODUCT_DECIMALLENGTH')
            )
        );
    }
    
    public function hookDisplayLeftColumnProduct($params) {
        
        if (Configuration::get('JRATINGPRODUCT_HOOK') == 'HOOK_EXTRA_LEFT') {
            //HOOK_EXTRA_LEFT
            $this->getDataFrontOffice();
            return $this->display(__FILE__, 'jratingproduct.tpl');
        }
    }
    
    public function hookDisplayProductButtons($params) {
        
        if (Configuration::get('JRATINGPRODUCT_HOOK') == 'HOOK_PRODUCT_ACTIONS') {
            //HOOK_PRODUCT_ACTIONS
            $this->getDataFrontOffice(); 
            return $this->display(__FILE__, 'jratingproduct.tpl');
        }
    }
    
    public function hookDisplayRightColumnProduct($params) {
        
        if (Configuration::get('JRATINGPRODUCT_HOOK') == 'HOOK_EXTRA_RIGHT') {
            //HOOK_EXTRA_RIGHT
            $this->getDataFrontOffice();  
            return $this->display(__FILE__, 'jratingproduct.tpl');
        } 
    }
    
    public function hookDisplayFooterProduct($params) {
        
        if (Configuration::get('JRATINGPRODUCT_HOOK') == 'HOOK_PRODUCT_FOOTER') {
            //HOOK_PRODUCT_FOOTER
            $this->getDataFrontOffice(); 
            return $this->display(__FILE__, 'jratingproduct.tpl');
        }
    }
    
    public function hookDisplayProductTab($params) {
        if (Configuration::get('JRATINGPRODUCT_HOOK') == 'HOOK_PRODUCT_TAB') {
            //HOOK_PRODUCT_TAB
            return $this->display(__FILE__, 'jratingproduct-tab.tpl');
        }
    }
    
    public function hookDisplayProductTabContent($params) {
        if (Configuration::get('JRATINGPRODUCT_HOOK') == 'HOOK_PRODUCT_TAB') {
            //HOOK_PRODUCT_TAB_CONTENT
            $this->getDataFrontOffice();
            $this->smarty->assign('jratingproduct_path', _PS_MODULE_DIR_.'jratingproduct/jratingproduct.tpl');
            return $this->display(__FILE__, 'jratingproduct-tabcontent.tpl');
        }
    }
   
    public function hookDisplayHeader() {
        $this->context->controller->addCSS($this->_path.'jquery/jRating.jquery.css', 'all');
         $this->context->controller->addJS($this->_path.'jquery/jRating.jquery.js');
    }
}
?>
